@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: mb_c.h 8919 2007-03-19 20:27:18Z luks $
+ * $Id: mb_c.h 9246 2007-07-07 06:40:33Z luks $
  */
  
 #ifndef __MUSICBRAINZ3_MB_C_H__
@@ -210,7 +210,7 @@ MB_API MbResultList
 mb_query_get_releases(MbQuery query, MbReleaseFilter flt);
 
 MB_API MbResultList
-mb_query_get_track(MbQuery query, MbTrackFilter flt);
+mb_query_get_tracks(MbQuery query, MbTrackFilter flt);
 
 /* {{{ MusicBrainz::Artist */
 
@@ -398,6 +398,14 @@ mb_release_get_text_script(MbRelease release, char *str, int len);
 MB_API void
 mb_release_get_asin(MbRelease release, char *str, int len);
 
+/**
+ * Returns the artist. 
+ *
+ * @see MusicBrainz::Release::getArtist
+ */
+MB_API MbArtist
+mb_release_get_artist(MbRelease release);
+
 /**
  * Returns the offset of the track list.
  *
@@ -645,6 +653,9 @@ mb_artist_includes_track_relations(MbArtistIncludes inc);
 MB_API MbArtistIncludes
 mb_artist_includes_url_relations(MbArtistIncludes inc);
 
+MB_API MbArtistIncludes
+mb_artist_includes_release_events(MbArtistIncludes inc);
+
 /* }}} */
 
 /* {{{ MusicBrainz::ReleaseIncludes */
