@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: mb_c.cpp 8919 2007-03-19 20:27:18Z luks $
+ * $Id: mb_c.cpp 9246 2007-07-07 06:40:33Z luks $
  */
  
 #include <string.h>
@@ -334,6 +334,13 @@ MB_C_OBJ_LIST_GETTER(Release, release, ReleaseEvents, release_events, ReleaseEve
 MB_C_OBJ_LIST_GETTER(Release, release, Relations, relations, Relation, relation, Relation)
 MB_C_STR_LIST_GETTER(Release, release, Types, types, Type, type)
 
+MB_API MbArtist
+mb_release_get_artist(MbRelease r)
+{
+	Release *release = (Release *)r;
+	return (MbArtist)release->getArtist();
+}
+
 /* === MusicBrainz::Track === */
 
 MB_C_FREE(Track, track)
@@ -367,6 +374,7 @@ MB_C_INCLUDES(ArtistIncludes, artist_includes, artistRelations, artist_relations
 MB_C_INCLUDES(ArtistIncludes, artist_includes, releaseRelations, release_relations)
 MB_C_INCLUDES(ArtistIncludes, artist_includes, trackRelations, track_relations)
 MB_C_INCLUDES(ArtistIncludes, artist_includes, urlRelations, url_relations)
+MB_C_INCLUDES(ArtistIncludes, artist_includes, releaseEvents, release_events)
 
 MbArtistIncludes
 mb_artist_includes_releases(MbArtistIncludes o, const char *str) 
