@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: mbxmlparser.cpp 8794 2007-01-18 23:37:36Z luks $
+ * $Id: mbxmlparser.cpp 9218 2007-06-25 20:11:09Z luks $
  */
  
 // TODO: support for namespaces and full MMD 
@@ -53,6 +53,8 @@ public:
 	void addReleaseEventsToList(XMLNode listNode, ReleaseEventList &resultList);
 	void addTracksToList(XMLNode listNode, TrackList &resultList);
 	void addUsersToList(XMLNode listNode, UserList &resultList);
+	void addTagsToList(XMLNode listNode, TagList &resultList);
+	void addLabelAliasesToList(XMLNode listNode, LabelAliasList &resultList);
 
 	template<typename T, typename TL, typename TR>
 	void addResults(XMLNode listNode, TL &resultList, T *(MbXmlParserPrivate::*creator)(XMLNode));
@@ -68,6 +70,9 @@ public:
 	ReleaseEvent *createReleaseEvent(XMLNode releaseNode);
 	Track *createTrack(XMLNode releaseNode);
 	User *createUser(XMLNode releaseNode);
+	Tag *createTag(XMLNode releaseNode);
+	Label *createLabel(XMLNode releaseNode);
+	LabelAlias *createLabelAlias(XMLNode releaseNode);
 
 	DefaultFactory factory;
 };
@@ -184,6 +189,9 @@ MbXmlParser::MbXmlParserPrivate::createArtist(XMLNode artistNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, artist);
 		}
+		else if (name == "tag-list") {
+			addTagsToList(node, artist->getTags());
+		}
 	}
 	return artist; 
 }
@@ -198,6 +206,69 @@ MbXmlParser::MbXmlParserPrivate::createArtistAlias(XMLNode node)
 	return alias;
 }
 
+Label *
+MbXmlParser::MbXmlParserPrivate::createLabel(XMLNode labelNode)
+{
+	Label *label = factory.newLabel();
+	label->setId(getIdAttr(labelNode, "id", "label"));
+	label->setType(getUriAttr(labelNode, "type"));
+	for (int i = 0; i < labelNode.nChildNode(); i++) {
+		XMLNode node = labelNode.getChildNode(i);
+		string name = node.getName(); 
+		if (name == "name") {
+			label->setName(getText(node));
+		}
+		else if (name == "sort-name") {
+			label->setSortName(getText(node));
+		}
+		else if (name == "disambiguation") {
+			label->setDisambiguation(getText(node));
+		}
+		else if (name == "life-span") {
+			const char *begin = node.getAttribute("begin");
+			const char *end = node.getAttribute("end");
+			if (begin)
+				label->setBeginDate(string(begin));
+			if (end)
+				label->setEndDate(string(end));
+		}
+		else if (name == "alias-list") {
+			addLabelAliasesToList(node, label->getAliases());
+		}
+		else if (name == "release-list") {
+			label->setReleasesOffset(getIntAttr(node, "offset"));
+			label->setReleasesCount(getIntAttr(node, "count"));
+			addReleasesToList(node, label->getReleases());
+		}
+		else if (name == "relation-list") {
+			addRelationsToEntity(node, label);
+		}
+		else if (name == "tag-list") {
+			addTagsToList(node, label->getTags());
+		}
+	}
+	return label; 
+}
+
+LabelAlias *
+MbXmlParser::MbXmlParserPrivate::createLabelAlias(XMLNode node)
+{
+	LabelAlias *alias = factory.newLabelAlias();
+	alias->setType(getUriAttr(node, "type"));
+	alias->setScript(getTextAttr(node, "script"));
+	alias->setValue(getText(node));
+	return alias;
+}
+
+Tag *
+MbXmlParser::MbXmlParserPrivate::createTag(XMLNode node)
+{
+	Tag *tag = factory.newTag();
+	tag->setCount(getIntAttr(node, "count"));
+	tag->setName(getText(node));
+	return tag;
+}
+
 
 string
 getResourceType(const string &type)
@@ -302,6 +373,9 @@ MbXmlParser::MbXmlParserPrivate::createRelease(XMLNode releaseNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, release);
 		}
+		else if (name == "tag-list") {
+			addTagsToList(node, release->getTags());
+		}
 	}
 	return release;
 }
@@ -331,6 +405,9 @@ MbXmlParser::MbXmlParserPrivate::createTrack(XMLNode trackNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, track);
 		}
+		else if (name == "tag-list") {
+			addTagsToList(node, track->getTags());
+		}
 	}
 	return track;
 }
@@ -369,6 +446,15 @@ MbXmlParser::MbXmlParserPrivate::createReleaseEvent(XMLNode releaseEventNode)
 	ReleaseEvent *releaseEvent = factory.newReleaseEvent();
 	releaseEvent->setCountry(getTextAttr(releaseEventNode, "country"));
 	releaseEvent->setDate(getTextAttr(releaseEventNode, "date"));
+	releaseEvent->setCatalogNumber(getTextAttr(releaseEventNode, "catalog-number"));
+	releaseEvent->setBarcode(getTextAttr(releaseEventNode, "barcode"));
+	for (int i = 0; i < releaseEventNode.nChildNode(); i++) {
+		XMLNode node = releaseEventNode.getChildNode(i);
+		string name = node.getName();
+		if (name == "label") {
+			releaseEvent->setLabel(createLabel(node));
+		}
+	}
 	return releaseEvent;
 }
 
@@ -454,6 +540,18 @@ MbXmlParser::MbXmlParserPrivate::addUsersToList(XMLNode listNode, UserList &resu
 	addToList<User, UserList>(listNode, resultList, &MbXmlParserPrivate::createUser);
 }
 
+void
+MbXmlParser::MbXmlParserPrivate::addTagsToList(XMLNode listNode, TagList &resultList)
+{
+	addToList<Tag, TagList>(listNode, resultList, &MbXmlParserPrivate::createTag);
+}
+
+void
+MbXmlParser::MbXmlParserPrivate::addLabelAliasesToList(XMLNode listNode, LabelAliasList &resultList)
+{
+	addToList<LabelAlias, LabelAliasList>(listNode, resultList, &MbXmlParserPrivate::createLabelAlias);
+}
+
 MbXmlParser::MbXmlParser(/*IFactory &factory*/)
 {
 	d = new MbXmlParserPrivate();
@@ -487,6 +585,9 @@ MbXmlParser::parse(const std::string &data)
 			else if (name == string("release")) {
 				md->setRelease(d->createRelease(node));
 			}
+			else if (name == string("label")) {
+				md->setLabel(d->createLabel(node));
+			}
 			else if (name == string("artist-list")) {
 				d->addArtistResults(node, md->getArtistResults());
 			}
