@@ -17,11 +17,13 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: releaseevent.cpp 8466 2006-09-05 08:59:44Z luks $
+ * $Id: releaseevent.cpp 9218 2007-06-25 20:11:09Z luks $
  */
  
 #include <string>
+#include <musicbrainz3/label.h>
 #include <musicbrainz3/releaseevent.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -30,10 +32,14 @@ class ReleaseEvent::ReleaseEventPrivate
 {
 public:
 	ReleaseEventPrivate()
+		: label(NULL)
 		{}
 		
 	string country;
 	string dateStr;
+	string catalogNumber;
+	string barcode;
+	Label *label;
 };
 
 ReleaseEvent::ReleaseEvent(const string &country, const string &dateStr)
@@ -46,30 +52,28 @@ ReleaseEvent::ReleaseEvent(const string &country, const string &dateStr)
 
 ReleaseEvent::~ReleaseEvent()
 {
+	if (d->label)
+		delete d->label;
+
 	delete d;
 }
 
-string
-ReleaseEvent::getCountry() const
-{
-	return d->country;
-}
+SIMPLE_STRING_SETTER_GETTER(ReleaseEvent, Country, country);
+SIMPLE_STRING_SETTER_GETTER(ReleaseEvent, CatalogNumber, catalogNumber);
+SIMPLE_STRING_SETTER_GETTER(ReleaseEvent, Barcode, barcode);
+SIMPLE_STRING_SETTER_GETTER(ReleaseEvent, Date, dateStr);
 
 void
-ReleaseEvent::setCountry(const string &value)
+ReleaseEvent::setLabel(Label *label)
 {
-	d->country = value;
+	if (d->label)
+		delete d->label;
+
+	d->label = label;
 }
 
-string
-ReleaseEvent::getDate() const
+Label *
+ReleaseEvent::getLabel()
 {
-	return d->dateStr;
+	return d->label;
 }
-
-void
-ReleaseEvent::setDate(const string &value)
-{
-	d->dateStr = value;
-}
-
